==> alkimia_8.1.1.orig.tar.xz: alkimia-8.1.1/tools/onlinequoteseditor/org.kde.onlinequoteseditor.desktop.cmake <==
# KDE Config File
[Desktop Entry]
Type=Application
Exec=onlinequoteseditor@TARGET_SUFFIX@
Icon=onlinequoteseditor@TARGET_SUFFIX@
X-DocPath=onlinequoteseditor@TARGET_SUFFIX@/index.html
Terminal=false
Name=Online Quotes Editor
Name[ca]=Editor de cotitzacions en línia
Name[ca@valencia]=Editor de cotitzacions en línia
Name[de]=Editor für Online-Kursnotizen
Name[el]=Επεξεργαστής προσφορών
Name[en_GB]=Online Quotes Editor
Name[es]=Editor de cotizaciones en línea
Name[et]=Võrgukursside redaktor
Name[eu]=Lerroko kotizazioen editorea
Name[fr]=Éditeur de cotations en ligne
Name[gl]=Editor de cotizacións de Internet
Name[hu]=Szerkesztő online árajánlatokhoz
Name[ia]=Editor de citationes in linea
Name[it]=Editor delle quotazioni in linea
Name[ko]=온라인 시세 편집기
Name[nl]=Bewerker voor Online koersen
Name[pl]=Edytor wycen z sieci
Name[pt]=Editor de Cotações 'Online'
Name[pt_BR]=Editor de cotações online
Name[ro]=Redactor de cotații online
Name[sk]=Editor online ponúk
Name[sl]=Urejevalni spletnih navedb
Name[sv]=Direktkurseditor
Name[uk]=Редактор інтернет-курсів
Name[x-test]=xxOnline Quotes Editorxx
Name[zh_CN]=在线报价编辑器
GenericName=Editor for online price quotes
GenericName[ca]=Editor per a la cotització en línia dels preus
GenericName[ca@valencia]=Editor per a la cotització en línia dels preus
GenericName[de]=Editor für Online-Kursnotizen
GenericName[el]=Επεξεργαστής για προσφορές τιμών
GenericName[en_GB]=Editor for online price quotes
GenericName[es]=Editor de cotizaciones de precios en línea
GenericName[et]=Võrgukursside hindade redaktor
GenericName[eu]=Prezioak lerroan kotizatzeko editorea
GenericName[fr]=Éditeur de cotations en ligne
GenericName[gl]=Editor de cotizacións de Internet
GenericName[hu]=Szerkesztő online árajánlatokhoz
GenericName[ia]=Editor per citationes de prcios in linea
GenericName[it]=Editor per le quotazioni dei prezzi in linea
GenericName[ko]=온라인 가격 시세 편집기
GenericName[nl]=Bewerker voor online koersen
GenericName[pl]=Edytor do wycen z sieci
GenericName[pt]=Editor para cotações de preços 'online'
GenericName[pt_BR]=Editor de cotações de preço online
GenericName[ro]=Redactor pentru cotații online de prețuri
GenericName[sk]=Editor pre online cenové ponuky
GenericName[sl]=Urejevalnik spletnih tečajnic
GenericName[sv]=Editor för direktkurser
GenericName[uk]=Редактор інтернет-курсів
GenericName[x-test]=xxEditor for online price quotesxx
GenericName[zh_CN]=在线报价编辑器
Comment=Editor for online price quotes used by finance applications
Comment[ca]=Editor per a la cotització en línia dels preus usat per les aplicacions financeres
Comment[ca@valencia]=Editor per a la cotització en línia dels preus usat per les aplicacions financeres
Comment[de]=Editor für Online-Kursnotizen für Finanz-Anwendungen
Comment[el]=Επεξεργαστής προσφορών τιμών για χρηματοοικονομικές εφαρμογές
Comment[en_GB]=Editor for online price quotes used by finance applications
Comment[es]=Editor de cotizaciones de precios en línea usado por aplicaciones de finanzas
Comment[et]=Finantsrakenduste võrgukursside hinna redaktor
Comment[eu]=Finantza-aplikazioek lerroko prezioen kotizazioetarako erabilitako editorea
Comment[fr]=Éditeur de cotations en ligne utilisé par les applications financières
Comment[gl]=Editor de cotizacións de Internet usado por aplicacións financeiras
Comment[hu]=Szerkesztő pénzügyi alkalmazások által használt online árajánlatokhoz
Comment[ia]=Editor per citationes de prcio in linea usate per applicationes de financia
Comment[it]=Editor per le quotazioni dei prezzi in linea utilizzate dalle applicazioni finanziarie
Comment[ko]=재무 관리 프로그램에서 사용하는 온라인 가격 시세 편집기
Comment[nl]=Bewerker voor online koersen gebruikt door financiële toepassingen
Comment[pl]=Edytor dla wycen z sieci używanych przez aplikacje finansowe
Comment[pt]=Editor para cotações de preços 'online' usadas pelas aplicações financeiras
Comment[pt_BR]=Editor de cotações de preço online usado por aplicativos financeiros
Comment[ro]=Redactor pentru cotații online de prețuri folosite de aplicațiile financiare
Comment[sk]=Editor pre online cenové ponuky používané finančnými aplikáciami
Comment[sl]=Urejevalnik spletnih navedb cen pridobljenih od finančnih aplikacij
Comment[sv]=Editor för direktkurser använda av ekonomiprogram
Comment[uk]=Редактор інтернет-курсів, який використовується у фінансових програмах
Comment[x-test]=xxEditor for online price quotes used by finance applicationsxx
Comment[zh_CN]=金融应用程序使用的在线报价编辑器
Categories=Qt;KDE;Office;Finance;

==> alkimia_8.1.2.orig.tar.xz: alkimia-8.1.2/tools/onlinequoteseditor/org.kde.onlinequoteseditor.desktop.cmake <==
# KDE Config File
[Desktop Entry]
Type=Application
Exec=onlinequoteseditor@TARGET_SUFFIX@
Icon=onlinequoteseditor@TARGET_SUFFIX@
X-DocPath=onlinequoteseditor@TARGET_SUFFIX@/index.html
Terminal=false
Name=Online Quotes Editor
Name[ca]=Editor de cotitzacions en línia
Name[ca@valencia]=Editor de cotitzacions en línia
Name[de]=Editor für Online-Kursnotizen
Name[el]=Επεξεργαστής προσφορών
Name[en_GB]=Online Quotes Editor
Name[es]=Editor de cotizaciones en línea
Name[et]=Võrgukursside redaktor
Name[eu]=Lerroko kotizazioen editorea
Name[fr]=Éditeur de cotations en ligne
Name[gl]=Editor de cotizacións de Internet
Name[hu]=Szerkesztő online árajánlatokhoz
Name[ia]=Editor de citationes in linea
Name[it]=Editor delle quotazioni in linea
Name[ka]=ონლაინ კვოტების რედაქტორი
Name[ko]=온라인 시세 편집기
Name[nl]=Bewerker voor Online koersen
Name[pl]=Edytor wycen z sieci
Name[pt]=Editor de Cotações 'Online'
Name[pt_BR]=Editor de cotações online
Name[ro]=Redactor de cotații online
Name[sk]=Editor online ponúk
Name[sl]=Urejevalni spletnih navedb
Name[sv]=Direktkurseditor
Name[tr]=Çevrimiçi Kurlar Düzenleyicisi
Name[uk]=Редактор інтернет-курсів
Name[x-test]=xxOnline Quotes Editorxx
Name[zh_CN]=在线报价编辑器
GenericName=Editor for online price quotes
GenericName[ca]=Editor per a la cotització en línia dels preus
GenericName[ca@valencia]=Editor per a la cotització en línia dels preus
GenericName[de]=Editor für Online-Kursnotizen
GenericName[el]=Επεξεργαστής για προσφορές τιμών
GenericName[en_GB]=Editor for online price quotes
GenericName[es]=Editor de cotizaciones de precios en línea
GenericName[et]=Võrgukursside hindade redaktor
GenericName[eu]=Prezioak lerroan kotizatzeko editorea
GenericName[fr]=Éditeur de cotations en ligne
GenericName[gl]=Editor de cotizacións de Internet
GenericName[hu]=Szerkesztő online árajánlatokhoz
GenericName[ia]=Editor per citationes de prcios in linea
GenericName[it]=Editor per le quotazioni dei prezzi in linea
GenericName[ka]=ონლაინ ფასების კვოტების რედაქტორი
GenericName[ko]=온라인 가격 시세 편집기
GenericName[nl]=Bewerker voor online koersen
GenericName[pl]=Edytor do wycen z sieci
GenericName[pt]=Editor para cotações de preços 'online'
GenericName[pt_BR]=Editor de cotações de preço online
GenericName[ro]=Redactor pentru cotații online de prețuri
GenericName[sk]=Editor pre online cenové ponuky
GenericName[sl]=Urejevalnik spletnih tečajnic
GenericName[sv]=Editor för direktkurser
GenericName[tr]=Çevrimiçi kurlar için düzenleyici
GenericName[uk]=Редактор інтернет-курсів
GenericName[x-test]=xxEditor for online price quotesxx
GenericName[zh_CN]=在线报价编辑器
Comment=Editor for online price quotes used by finance applications
Comment[ca]=Editor per a la cotització en línia dels preus usat per les aplicacions financeres
Comment[ca@valencia]=Editor per a la cotització en línia dels preus utilitzat per les aplicacions financeres
Comment[de]=Editor für Online-Kursnotizen für Finanz-Anwendungen
Comment[el]=Επεξεργαστής προσφορών τιμών για χρηματοοικονομικές εφαρμογές
Comment[en_GB]=Editor for online price quotes used by finance applications
Comment[es]=Editor de cotizaciones de precios en línea usado por aplicaciones de finanzas
Comment[et]=Finantsrakenduste võrgukursside hinna redaktor
Comment[eu]=Finantza-aplikazioek lerroko prezioen kotizazioetarako erabilitako editorea
Comment[fr]=Éditeur de cotations en ligne utilisé par les applications financières
Comment[gl]=Editor de cotizacións de Internet usado por aplicacións financeiras.
Comment[hu]=Szerkesztő pénzügyi alkalmazások által használt online árajánlatokhoz
Comment[ia]=Editor per citationes de prcio in linea usate per applicationes de financia
Comment[it]=Editor per le quotazioni dei prezzi in linea utilizzate dalle applicazioni finanziarie
Comment[ka]=ფინანსური აპლიკაციების მიერ გამოყენებული ონლაინ ფასების კვოტების რედაქტორი
Comment[ko]=재무 앱에서 사용하는 온라인 가격 시세 편집기
Comment[nl]=Bewerker voor online koersen gebruikt door financiële toepassingen
Comment[pl]=Edytor dla wycen z sieci używanych przez aplikacje finansowe
Comment[pt]=Editor para cotações de preços 'online' usadas pelas aplicações financeiras
Comment[pt_BR]=Editor de cotações de preço online usado por aplicativos financeiros
Comment[ro]=Redactor pentru cotații online de prețuri folosite de aplicațiile financiare
Comment[sk]=Editor pre online cenové ponuky používané finančnými aplikáciami
Comment[sl]=Urejevalnik spletnih navedb cen pridobljenih od finančnih aplikacij
Comment[sv]=Editor för direktkurser använda av ekonomiprogram
Comment[tr]=Finans uygulamaları tarafından kullanılan çevrimiçi kurlar düzenleyicisi
Comment[uk]=Редактор інтернет-курсів, який використовується у фінансових програмах
Comment[x-test]=xxEditor for online price quotes used by finance applicationsxx
Comment[zh_CN]=金融应用程序使用的在线报价编辑器
Categories=Qt;KDE;Office;Finance;
